{% extends "cow/base.html" %}

{% block content %}
    <div class="bs-callout bs-callout-warning">
        <h4>Page detail for: {{ page.name }}</h4>
        <article>{{ page.content|safe }}</article>
    </div>
{% endblock %}
