{% extends "cow/base.html" %}

{% block content %}
<table class="table table-hover">
    <thead>
        <tr>
            <th>name</th>
            <th>content</th>
            <th>created</th>
            <th>updated</th>
        </tr>
    </thead>
    <tbody>
        {% for page in object_list %}
            <tr>
                <td><a href="{% url 'page_detail' page.id %}">{{ page.name }}</a></td>
                <td>{{ page.content|slice:"0:199" }}...</td>
                <td>{{ page.created }}</td>
                <td>{{ page.last_updated }}</td>
            </tr>
        {% endfor %}
    </tbody>
</table>
{% endblock %}
